==> zio-aws-cognitoidentityprovider_2.12-5.17.102.8-sources.jar: zio/aws/cognitoidentityprovider/model/AnalyticsMetadataType.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cognitoidentityprovider.model.primitives.StringType
import scala.jdk.CollectionConverters._
final case class AnalyticsMetadataType(
    analyticsEndpointId: Option[StringType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.AnalyticsMetadataType = {
    import AnalyticsMetadataType.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.AnalyticsMetadataType
      .builder()
      .optionallyWith(
        analyticsEndpointId.map(value =>
          StringType.unwrap(value): java.lang.String
        )
      )(_.analyticsEndpointId)
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly =
    zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType
      .wrap(buildAwsValue())
}
object AnalyticsMetadataType {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.AnalyticsMetadataType
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType =
      zio.aws.cognitoidentityprovider.model
        .AnalyticsMetadataType(analyticsEndpointId.map(value => value))
    def analyticsEndpointId: Option[StringType]
    def getAnalyticsEndpointId: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("analyticsEndpointId", analyticsEndpointId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.AnalyticsMetadataType
  ) extends zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly {
    override val analyticsEndpointId: Option[StringType] = scala
      .Option(impl.analyticsEndpointId())
      .map(value =>
        zio.aws.cognitoidentityprovider.model.primitives.StringType(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.AnalyticsMetadataType
  ): zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cognitoidentityprovider_2.13-5.17.130.6-sources.jar: zio/aws/cognitoidentityprovider/model/AnalyticsMetadataType.scala <==
package zio.aws.cognitoidentityprovider.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cognitoidentityprovider.model.primitives.StringType
import scala.jdk.CollectionConverters._
final case class AnalyticsMetadataType(
    analyticsEndpointId: Option[StringType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentityprovider.model.AnalyticsMetadataType = {
    import AnalyticsMetadataType.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentityprovider.model.AnalyticsMetadataType
      .builder()
      .optionallyWith(
        analyticsEndpointId.map(value => value: java.lang.String)
      )(_.analyticsEndpointId)
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly =
    zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType
      .wrap(buildAwsValue())
}
object AnalyticsMetadataType {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentityprovider.model.AnalyticsMetadataType
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType =
      zio.aws.cognitoidentityprovider.model
        .AnalyticsMetadataType(analyticsEndpointId.map(value => value))
    def analyticsEndpointId: Option[StringType]
    def getAnalyticsEndpointId: ZIO[Any, AwsError, StringType] =
      AwsError.unwrapOptionField("analyticsEndpointId", analyticsEndpointId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.AnalyticsMetadataType
  ) extends zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly {
    override val analyticsEndpointId: Option[StringType] =
      scala.Option(impl.analyticsEndpointId()).map(value => value: StringType)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentityprovider.model.AnalyticsMetadataType
  ): zio.aws.cognitoidentityprovider.model.AnalyticsMetadataType.ReadOnly =
    new Wrapper(impl)
}
